@@ -1,19 +1,21 @@
-from siges_sdk.core.gateway import CoreGateway, PluginRegisterRequest, Dependencies, Table
+from siges_sdk.core.gateway import CoreGateway, PluginRegister, Dependencies, Table, Frontend
 from siges_sdk.core.gateway_provider import get_core_gateway
 
 try:
     __all__ = [
         "CoreGateway", 
-        "PluginRegisterRequest", 
+        "PluginRegister", 
         "Dependencies", 
         "Table", 
+        "Frontend",
         "get_core_gateway"
     ]
 except ImportError:
     __all__ = [
         "CoreGateway", 
-        "PluginRegisterRequest", 
+        "PluginRegister", 
         "Dependencies", 
         "Table", 
+        "Frontend",
         "get_core_gateway"
     ] 
\ No newline at end of file
